@@ -1,5 +1,6 @@
 validTCopula <- function(object) {
-  df <- object@df
+  param <- object@parameters
+  df <- param[length(param)]
   if (df <= 0) return ("df should be > 0")
   validEllipCopula(object)
 }
@@ -15,22 +16,30 @@ setClass("tCopula",
 tCopula <- function(param, dim = 2, dispstr = "ex", df = 5) {
   pdim <- length(param)
   val <- new("tCopula",
-             df = df,
              dispstr = dispstr,
              dimension = dim,
-             parameters = param,
-             param.names = paste("rho", 1:pdim, sep="."),
-             param.lowbnd = rep(-1, pdim),
-             param.upbnd = rep(1, pdim),
-             message = "t copula family")
+             parameters = c(param, df),
+             param.names = c(paste("rho", 1:pdim, sep="."), "df"),
+             param.lowbnd = c(rep(-1, pdim), 0),
+             param.upbnd = c(rep(1, pdim), Inf),
+             message = "t copula family",
+             getRho = function(obj) {
+               param <- obj@parameters
+               param[-length(param)]
+             }
+             )
   val
 }
 
-
+getdf <- function(object) {
+  param <- object@parameters
+  df <- param[length(param)]
+  df
+}
 
 rtCopula <- function(copula, n) {
   dim <- copula@dimension
-  df <- copula@df
+  df <- getdf(copula)
   sigma <- getSigma(copula)
   pt(rmvt(n, sigma = sigma, df = df), df = df)
 }
@@ -39,7 +48,7 @@ rtCopula <- function(copula, n) {
 ptCopula <- function(copula, u) {
   dim <- copula@dimension
   sigma <- getSigma(copula)
-  df <- copula@df
+  df <- getdf(copula)
   mycdf.vector <- function(x) {
     pmvt(lower = rep(-Inf, dim), upper = qt(x, df = df), sigma = sigma, df = df)
   }
@@ -53,7 +62,7 @@ ptCopula <- function(copula, u) {
 dtCopula <- function(copula, u) {
   dim <- copula@dimension
   sigma <- getSigma(copula)
-  df <- copula@df
+  df <- getdf(copula)
   if (is.vector(u)) u <- matrix(u, ncol = dim)
   x <- qt(u, df)
   val <- dmst(x, Omega = sigma, alpha = rep(0, dim),  df = df) /
@@ -66,7 +75,6 @@ dtCopula <- function(copula, u) {
 showTCopula <- function(object) {
   showCopula(object)
   if (object@dimension > 2) cat("dispstr: ", object@dispstr, "\n")
-  cat("df: ", object@df, "\n")
 }
 
 
@@ -75,3 +83,4 @@ setMethod("pcopula", signature("tCopula"), ptCopula)
 setMethod("dcopula", signature("tCopula"), dtCopula)
 
 setMethod("show", signature("tCopula"), showTCopula)
+
